## besio
::: pybes3.wrap_uproot
::: pybes3.open
::: pybes3.concatenate
::: pybes3.open_raw
::: pybes3.concatenate_raw

## detectors
::: pybes3.get_cgem_id
::: pybes3.get_emc_id
::: pybes3.get_mdc_id
::: pybes3.get_muc_id
::: pybes3.get_tof_id
::: pybes3.parse_cgem_id
::: pybes3.parse_emc_id
::: pybes3.parse_mdc_id
::: pybes3.parse_muc_id
::: pybes3.parse_tof_id

## tracks
::: pybes3.parse_helix